NLSL: setprm.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
setprm.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | setprm (ixparm, ixsite, fval)
| This file contains two routines that set a given parameter, specified by an index into the fparm or iparm array, given the parameter value and a site/spectrum index. The secondary index is interpreted according to whether or not the parameter belongs to a set of parameters that must be the same for all components of a given spectrum. This set of "spectral parameters" includes. More...
subroutine | setipr (ixparm, ixsite, ival)
| Analogous routine to setprm for integer parameters There are only two user-settable integer spectrum parameters: nfield, and ideriv. These are normally determined by the input data file, but are needed when calculations are to performed without data or fitting. More...
logical function | spcpar (ix)
| Returns .true. if the index argument corresponds to a floating point or integer parameter that cannot change for an individual spectrum, regardless of the number of sites for which the calculation is made. These include: More...
character *7 function | ptype (ix)
integer function | ixlim (ix)
double precision function | getprm (ixparm, ixsite)
| Given a parameter index and a site/spectrum index, this function returns the value of the parameter from the fparm array (for site parameters) or from the spectral parameter arrays for spectrum parameters. More...

## Function/Subroutine Documentation

double precision function getprm | ( | integer | ixparm,
|  | integer | ixsite
| ) |  |

Given a parameter index and a site/spectrum index, this function returns the value of the parameter from the fparm array (for site parameters) or from the spectral parameter arrays for spectrum parameters.

Definition at line 331 of file setprm.f90.

integer function ixlim | ( | integer | ix | ) |

Definition at line 300 of file setprm.f90.

character*7 function ptype | ( | integer | ix | ) |

Definition at line 285 of file setprm.f90.

subroutine setipr | ( | integer | ixparm,
|  | integer | ixsite,
|  | integer | ival
| ) |  |

Analogous routine to setprm for integer parameters There are only two user-settable integer spectrum parameters: nfield, and ideriv. These are normally determined by the input data file, but are needed when calculations are to performed without data or fitting.

Definition at line 142 of file setprm.f90.

Here is the caller graph for this function:

subroutine setprm | ( | integer | ixparm,
|  | integer | ixsite,
|  | double precision | fval
| ) |  |

This file contains two routines that set a given parameter, specified by an index into the fparm or iparm array, given the parameter value and a site/spectrum index. The secondary index is interpreted according to whether or not the parameter belongs to a set of parameters that must be the same for all components of a given spectrum. This set of "spectral parameters" includes.

PHASE (spectral phase angle) PSI (director tilt angle) B0 (spectrometer field) LB (spectral line broadening) RANGE (spectral range)

and is identified by the logical function spcpar(index) coded in this file. These parameters are kept arrays separate from the fparm arrays in which the site parameters are kept.

The index ixsite is interpreted as referring to a spectrum for spectral parameters; otherwise, the index refers to a component within a given spectrum.

Whenever a parameter is changed, if recalculation of a spectrum with the new parameter value would require recalculation of the tridiagonal matrix, a flag is set for the given sites/spectra affected by that parameter.

Definition at line 34 of file setprm.f90.

Here is the caller graph for this function:

logical function spcpar | ( | integer | ix | ) |

Returns .true. if the index argument corresponds to a floating point or integer parameter that cannot change for an individual spectrum, regardless of the number of sites for which the calculation is made. These include:

PHASE (spectral phase angle) PSI (director tilt angle) LB (spectral line broadening) B0 (spectrometer field) FIELDI (initial field of spectrum) DFLD (field step per point in spectrum) RANGE (field range of spectrum)

NFIELD (number of points in spectrum) IDERIV (0th/1st derivative flag for spectrum)

Definition at line 263 of file setprm.f90.